@@ -1,8 +1,8 @@
 test_that("TerminatorRunTime works", {
-  skip_on_cran()
+    skip_on_cran()
 
   terminator = trm("run_time", secs = 1)
-  expect_output(print(terminator), "TerminatorRunTime")
+  expect_snapshot(terminator)
   now = Sys.time()
   inst = MAKE_INST_2D(terminator)
   a = random_search(inst, batch_size = 1L)
@@ -23,7 +23,7 @@ test_that("max and current works", {
 
 test_that("TerminatorRunTime works with empty archive", {
   terminator = TerminatorRunTime$new()
-  archive = Archive$new(ps(x = p_dbl()), ps(y = p_dbl(tags = "minimize")))
+  archive = ArchiveBatch$new(ps(x = p_dbl()), ps(y = p_dbl(tags = "minimize")))
   expect_false(terminator$is_terminated(archive))
 })
 
